import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle{
	id:root;
	property GEditPopup popup;
	property alias textEdit: flick;
	onStateChanged :{
		if (bmUrl.state == "menu"){
			popup.visible = true;
		}else{
			popup.visible = false;
		}
	}
	
	BorderImage {
		id: startHandle;
		source: "images/handle.png";
		opacity: 0.0;
		width: 24;
		height: bmUrl.positionToRectangle(bmUrl.selectionStart).height + 3;
		x: bmUrl.positionToRectangle(bmUrl.selectionStart).x - flick.contentX-width + 10;
		y: bmUrl.positionToRectangle(bmUrl.selectionStart).y - flick.contentY;
	}

	BorderImage {
		id: endHandle;
		source: "images/handle.png";
		opacity: 0.0;
		height: bmUrl.positionToRectangle(bmUrl.selectionEnd).height + 3;
		width: 24;
		x: bmUrl.positionToRectangle(bmUrl.selectionEnd).x - flick.contentX - 10;
		y: bmUrl.positionToRectangle(bmUrl.selectionEnd).y - flick.contentY;
	}


	Flickable {
		id: flick;
		property alias editor:bmUrl;
		
		anchors.fill: parent;
		contentWidth: bmUrl.paintedWidth;
		contentHeight: bmUrl.paintedHeight;
		interactive: true;
		clip: true;

		function ensureVisible(r) {
			 if (contentX >= r.x)
				 contentX = r.x;
			 else if (contentX+width <= r.x+r.width)
				 contentX = r.x+r.width-width;
			 if (contentY >= r.y)
				 contentY = r.y;
			 else if (contentY+height <= r.y+r.height)
				 contentY = r.y+r.height-height;
		}
		
		TextEdit{
			id:bmUrl;
			states: [
				State {
					name : "off";
					PropertyChanges {
						target: startHandle;
						opacity: 0.0;
						visible: false;
					}
					PropertyChanges {
						target: endHandle;
						opacity: 0.0;
						visible: false;
					}
					PropertyChanges {
						target: popup;
						visible:false;
					}
				},
				State {
					name: "selection"
					PropertyChanges {
						target: startHandle;
						opacity: 1.0;
					}
					PropertyChanges {
						target: endHandle;
						opacity: 1.0;
					}
				},
				State {
					name: "menu"
					PropertyChanges {
						target: startHandle;
						opacity: 0.5
					}
					PropertyChanges {
						target: endHandle;
						opacity: 0.5
					}
					PropertyChanges {
						target: popup;
						opacity: 1.0;
						visible:true;
					}
				}
			]
			
			width:flick.width;
			height:flick.height;
			activeFocusOnPress:true;
			onCursorRectangleChanged: flick.ensureVisible(cursorRectangle);
			MouseArea {

				property string drag: "";
				property int lastPressedX;
				property int lastPressedY;

				x: -startHandle.width
				y: 0;
				width: parent.width+startHandle.width+endHandle.width;
				height: parent.height;
				
				onPressAndHold: {
					if (bmUrl.state == "") {
						bmUrl.cursorPosition = bmUrl.positionAt(mouseX+x,mouseY+y);
						bmUrl.selectWord();
						bmUrl.state = "selection";
					}
				}

				onClicked: {
					bmUrl.forceActiveFocus();
					bmUrl.openSoftwareInputPanel();
					if (bmUrl.state == "") {
						bmUrl.cursorPosition = bmUrl.positionAt(mouseX+x,mouseY+y);
						if (!bmUrl.focus)
							bmUrl.focus = true;
					}
				}
/*				
				function hitHandle(h,x,y) {
					var result = false;
					result = (x>=h.x+flick.contentX)
							&& (x<h.x+flick.contentX+h.width)
							&& (y>=h.y+flick.contentY)
							&& (y<h.y+flick.contentY+h.height);
					console.debug("HITHANDLE RESULT " + result + " FOR HANDLE " + h);
					return result;
				}
*/
				function hitIsLeft(h, x){
					return x < h.x;
				}
				function hitIsRight(h, x){
					return x > h.x + h.width;
				}
				
				onPressed: {
					lastPressedX = mouse.x;
					lastPressedY = mouse.y;
					if (bmUrl.state == "selection") {
						if (hitIsLeft(startHandle,mouse.x+x)&& drag!="end" && drag!="start") {
							drag = "start"
							flick.interactive = false
						} else if (hitIsRight(endHandle,mouse.x+x) && drag!="end" && drag!="start") {
							drag = "end"
							flick.interactive = false
						} else {
							var pos = bmUrl.positionAt(mouse.x+x,mouse.y+y);
							if (pos >= bmUrl.selectionStart && pos <= bmUrl.selectionEnd) {
								drag = "selection"
								flick.interactive = false
							} else {
								drag = ""
								flick.interactive = true
							}
						}
					}
				}

				onReleased: {
					lastPressedX = -1;
					lastPressedY = -1;
					console.debug ("onreleased_"+bmUrl.state + ";onreleased_drag_"+drag);
					if (bmUrl.state == "selection") {
						if (drag == "selection") {
							console.debug("root state e menu!!!");
							bmUrl.state = "menu"
						}
						drag = ""
					}
					flick.interactive = true
				}


				onPositionChanged: {
					if (bmUrl.state == "selection" && drag != "") {
						if (drag == "start") {
							var pos = bmUrl.positionAt(mouseX+x+startHandle.width/2,mouseY+y);
							var e = bmUrl.selectionEnd;
							var delta = pos - bmUrl.positionAt(lastPressedX, lastPressedY);
							var start = bmUrl.selectionStart - delta;
							console.debug ("LAST X " + lastPressedX + " LAST Y " + lastPressedY);
							console.debug ("DELTA " + delta + " start " + start);
							if (e < pos) //no overflow on end
								e = pos;
							bmUrl.select(start,e);
							lastPressedX = x;
							lastPressedY = y;
						} else if (drag == "end") {
							var pos = bmUrl.positionAt(mouseX+x-endHandle.width/2,mouseY+y);
							var s = bmUrl.selectionStart;
							if (s > pos)
								s = pos;
							bmUrl.select(s,pos);
						}
					}
				}				
/*
				onPositionChanged: {
					if (bmUrl.state == "selection" && drag != "") {
						if (drag == "start") {
							var pos = bmUrl.positionAt(mouseX+x+startHandle.width/2,mouseY+y);
							var e = bmUrl.selectionEnd;
							if (e < pos)
								e = pos;
							bmUrl.select(e-,e);
						} else if (drag == "end") {
							var pos = bmUrl.positionAt(mouseX+x-endHandle.width/2,mouseY+y);
							var s = bmUrl.selectionStart;
							if (s > pos)
								s = pos;
							bmUrl.select(s,pos);
						}
					}
				}				
*/
			}
		}
	}
}